@@ -1,10 +1,10 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
 from .payment_term import *
 from .invoice import *
-from .party import *
+from . import party
 from .account import *
 
 
@@ -12,26 +12,38 @@ def register():
     Pool.register(
         PaymentTerm,
         PaymentTermLine,
+        PaymentTermLineRelativeDelta,
+        TestPaymentTermView,
+        TestPaymentTermViewResult,
         Invoice,
         InvoicePaymentLine,
         InvoiceLine,
         InvoiceLineTax,
         InvoiceTax,
-        PrintInvoiceWarning,
         PayInvoiceStart,
         PayInvoiceAsk,
         CreditInvoiceStart,
-        Address,
-        Party,
-        FiscalYear,
+        party.Address,
+        party.ContactMechanism,
+        party.Party,
+        party.PartyPaymentTerm,
+        InvoiceSequence,
+        # Match pattern migration fallbacks to Fiscalyear values so Period
+        # must be registered before Fiscalyear
         Period,
+        FiscalYear,
         Move,
+        MoveLine,
         Reconciliation,
+        PaymentMethod,
         module='account_invoice', type_='model')
     Pool.register(
-        PrintInvoice,
+        TestPaymentTerm,
         PayInvoice,
         CreditInvoice,
+        party.PartyReplace,
+        party.PartyErase,
+        RenewFiscalYear,
         module='account_invoice', type_='wizard')
     Pool.register(
         InvoiceReport,
